/* Generated automatically. */
static const char configuration_arguments[] = "/home/freetz/freetz-ng/source/toolchain-mips_gcc-8.3.0_uClibc-1.0.40-nptl_kernel-4.9/gcc-8.3.0/configure --prefix=/home/freetz/freetz-ng/toolchain/build/mips_gcc-8.3.0_uClibc-1.0.40-nptl_kernel-4.9/mips-linux-uclibc --with-sysroot=/home/freetz/freetz-ng/toolchain/build/mips_gcc-8.3.0_uClibc-1.0.40-nptl_kernel-4.9/mips-linux-uclibc/usr/ --build=x86_64-pc-linux-gnu --host=x86_64-pc-linux-gnu --target=mips-linux-uclibc --enable-languages=c,c++ --enable-shared --enable-threads --with-gmp=/home/freetz/freetz-ng/tools/build --with-mpfr=/home/freetz/freetz-ng/tools/build --with-mpc=/home/freetz/freetz-ng/tools/build --with-isl=no --enable-option-checking --with-gnu-as --with-gnu-ld --disable-__cxa_atexit --disable-libgomp --disable-libmudflap --disable-libsanitizer --disable-libssp --disable-multilib --enable-tls --disable-fixed-point --with-arch=mips32r2 --with-abi=32 --with-float=soft --disable-nls --with-mips-plt --disable-decimal-float";
static const char thread_model[] = "posix";

static const struct {
  const char *name, *value;
} configure_default_options[] = { { "abi", "32" }, { "arch", "mips32r2" }, { "float", "soft" }, { "llsc", "llsc" }, { "mips-plt", "plt" } };
